Apps distributed by the AppStore are encrypted using an encryption scheme similar to the FairPlay DRM.

The encryption is specific to the device that retrieved the application from AppStore and can only be decrypted on that
device.

Encrypted applications are impossible to analyze and will limit the scan results of Ostorlab.